package com.lejos.programmingbook.pong;

import lejos.hardware.Brick;
import lejos.hardware.BrickFinder;
import lejos.hardware.lcd.GraphicsLCD;

/**
 * The <code>Ball</code> class represents the ball of the Pong game.<br>
 * A ball has a position on the screen and a velocity (horizontal/vertical velocity).<br>
 * 
 * This class is able to paint itself and perform an action consisting of
 * the ball's movement and top/bottom collision detection.
 * 
 * @author Alexander Schulze
 */
public class Ball {
	public static int SIZE = 3;
	public static int MIDDLE_X = 89;
	public static int MIDDLE_Y = 64;

	private int posY = 0;
	private int posX = 0;

	private int vx = 0;
	private int vy = 0;

	private Brick ev3 = null;

	public Ball() {
		ev3 = BrickFinder.getDefault();
	}

	public void init() {
		posX = MIDDLE_X;
		posY = MIDDLE_Y;
		vx = (int) (Math.random() * 7 - 4);
		if (vx == 0) {
			vx = 2;
		}
		vy = (int) (Math.random() * 5 - 3);
	}

	public void paint() {
		GraphicsLCD g = ev3.getGraphicsLCD();
		g.drawArc(posX, posY, SIZE, SIZE, 0, 360);
	}

	public void action() {
		posX = posX + vx;
		posY += vy;
		// test for ball contact at the top and the bottom
		if ((posY < 10) || (posY > 120)) {
			vy = vy * (-1);
		}
	}
	
	public int getPosX() {
		return posX;
	}

	public int getPosY() {
		return posY;
	}
	
	public void inverse() {
		vx = vx * (-1);
	}

}
