package com.lejos.programmingbook.pong;

import lejos.hardware.lcd.LCD;
import lejos.hardware.motor.EV3LargeRegulatedMotor;

/**
 * The <code>Player</code> class represents one player of the Pong game. Each
 * player has one racket and a score.<br>
 * This class is able to paint itself and perform an action consisting of
 * controller movement and goal checking by delegating this call to the racket.
 * 
 * @author Alexander Schulze
 */
public class Player {
	private int score = 0;
	private int scorePosX = 0;

	private Racket racket = null;

	public Player(int scorePosX, int racketPosX, EV3LargeRegulatedMotor controller, GoalChecker goalChecker) {
		this.scorePosX = scorePosX;
		racket = new Racket(racketPosX, controller, goalChecker);
	} 

	public void init() {
		racket.init();
	}

	public void paint() {
		LCD.drawString(String.valueOf(score), scorePosX, 0);
		racket.paint();
	}
	
	public void addScore() {
		score++;
	}

	public boolean action(Ball ball) {
		return racket.action(ball);
	}

}
