package com.lejos.programmingbook.pong;

import lejos.hardware.Button;
import lejos.hardware.Sound;
import lejos.hardware.lcd.LCD;
import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.port.MotorPort;
import lejos.utility.Delay;

/**
 * Implementation of Pong for EV3<P>
 * 
 * This implementation uses an object-oriented programming style and uses
 * separate classes for the different functionalities.
 * 
 * @author Alexander Schulze
 */
public class PongGame {

	private Player player1 = null;
	private Player player2 = null;
	private Ball ball = null;

	public PongGame() {
		EV3LargeRegulatedMotor motorB = new EV3LargeRegulatedMotor(MotorPort.B);
		EV3LargeRegulatedMotor motorC = new EV3LargeRegulatedMotor(MotorPort.C);
		player1 = new Player(3, 20, motorB, new GoalChecker() {
			@Override
			public boolean checkForGoal(int ballPosX) {
				return ballPosX < 22;
			}
		});
		player2 = new Player(12, 158, motorC, new GoalChecker() {
			@Override
			public boolean checkForGoal(int ballPosX) {
				return ballPosX > 156;
			}
		});
		ball = new Ball();
	}

	public void init() {
		player1.init();
		player2.init();
		ball.init();
	}

	private void paintGame() {
		LCD.clear();
		ball.paint();
		player1.paint();
		player2.paint();
	}

	public void playGame() {
		boolean runGame = true;
		while (true) {
			runGame = true;
			ball.init();
			paintGame();
			Button.waitForAnyPress();
			while (runGame) {
				ball.action();
				if (player1.action(ball)) {
					player2.addScore();
					runGame = false;
				}
				if (player2.action(ball)) {
					player1.addScore();
					runGame = false;
				}
				paintGame();
				Delay.msDelay(100);
			}
			Sound.playTone(783, 1000);
		}

	}

	public static void main(String[] args) {

		PongGame pong = new PongGame();
		pong.init();
		pong.playGame();

	}

}
