package com.lejos.programmingbook.pong;

import lejos.hardware.Brick;
import lejos.hardware.BrickFinder;
import lejos.hardware.lcd.GraphicsLCD;
import lejos.hardware.motor.EV3LargeRegulatedMotor;

/**
 * The <code>Racket</code> class represents the racket of the Pong game. <br>
 * This class is able to paint itself and perform an action consisting of
 * controller movement and goal checking.
 * 
 * @author Alexander Schulze
 */
public class Racket {
	public static int SIZE = 20;
	public static int START_Y_POS = 20;

	private int posY = 0;
	private int posX = 0;

	private Brick ev3 = null;
	private EV3LargeRegulatedMotor controller = null;
	private GoalChecker goalChecker = null;

	/**
	 * Instantiates a new instance of a racket
	 * 
	 * @param posX the x position of the racket on the screen
	 * @param controller the controller responsible to control the racket
	 * @param goalChecker the goal checker instance to verify a goal
	 */
	public Racket(int posX, EV3LargeRegulatedMotor controller, GoalChecker goalChecker) {
		this.posX = posX;
		ev3 = BrickFinder.getDefault();
		this.controller = controller;
		this.goalChecker = goalChecker;
	}

	public void init() {
		posY = START_Y_POS;
		controller.resetTachoCount();
	}

	public void paint() {
		GraphicsLCD g = ev3.getGraphicsLCD();
		g.drawLine(posX, posY, posX, posY + SIZE);
	}

	public boolean action(Ball ball) {
		// set position of racket
		posY = controller.getTachoCount();
		if (posY < 0) {
			posY = 0;
		} else if (posY > 108) {
			posY = 108;
		}
		// check for contact
		if (goalChecker.checkForGoal(ball.getPosX())) {
			if ((ball.getPosY() - posY <= SIZE) && (ball.getPosY() - posY >= 0)) {
				// ball contact to racket
				ball.inverse();
			} else {
				return true;
			}
		}
		return false;
	}

}
