package com.lejos.programmingbook.roomscanner;

import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import de.lejos.fwk.sensor.IRSensor;
import lejos.hardware.Brick;
import lejos.hardware.BrickFinder;
import lejos.hardware.Button;
import lejos.hardware.lcd.GraphicsLCD;
import lejos.hardware.lcd.LCD;
import lejos.hardware.motor.EV3LargeRegulatedMotor;
import lejos.hardware.port.MotorPort;
import lejos.hardware.port.SensorPort;
import lejos.utility.Delay;

public class A62_RoomScanner {

	// header is LNI0 => 0x4c4e4930 (big endian)
	// taken from lejos.hardware.lcd.Image
	private static final int LNI0_HEADER = 0x4c4e4930;

	public static void saveLCDasPicture() {
		byte[] frameBuffer = LCD.getDisplay();
		String fileName = "room_" + System.currentTimeMillis() + ".lni";
		try (DataOutputStream out = new DataOutputStream(new FileOutputStream(new File(fileName)))) {
			out.writeInt(LNI0_HEADER);
			out.writeShort(178);
			out.writeShort(128);
			out.write(frameBuffer);
			out.flush();
		} catch (IOException ioex) {
			System.out.println("Error writing file: " + ioex);
		}
	}

	public static void main(String[] args) {

		Brick ev3 = BrickFinder.getDefault();
		GraphicsLCD lcd = ev3.getGraphicsLCD();
		lcd.clear();
		EV3LargeRegulatedMotor motor = new EV3LargeRegulatedMotor(MotorPort.A);
		// EV3MediumRegulatedMotor motor = new EV3MediumRegulatedMotor(MotorPort.A);
		motor.setSpeed(300);
		IRSensor irsensor = new IRSensor(SensorPort.S1);
		motor.resetTachoCount();

		int uebersetzung = 1;
		int transformation = 1;
		float entfernung = 0;
		int grad = 0;
		double bogenmass = 0;
		int x = 0;
		int y = 0;

		do {
			entfernung = irsensor.getDistance();
			if (entfernung > 300) {
				// Entfernung limitieren
				entfernung = 300;
			}
			// lcd.drawString(Float.toString(entfernung), 0, 0, GraphicsLCD.HCENTER);

			grad = motor.getTachoCount();
			bogenmass = (grad * Math.PI) / 180;

			x = (int) (entfernung * Math.cos(bogenmass / uebersetzung) * transformation + 88);
			y = (int) (entfernung * Math.sin(bogenmass / uebersetzung) * transformation + 63);

			motor.rotate(2);
			lcd.drawLine(88, 63, x, y);

		} while (motor.getTachoCount() < (360 * uebersetzung));

		Delay.msDelay(1000);

		motor.setSpeed(500);
		motor.backward();
		while (motor.getTachoCount() > 0) {
		}

		motor.stop();
		motor.close();
		irsensor.close();

		Button.waitForAnyPress();

		saveLCDasPicture();

	}

}
